
package org.objectweb.fractal.cecilia.adl.implementations;

import org.objectweb.fractal.adl.implementations.Implementation;

/**
 * AST Node interface which adds a <code>language</code> attribute to
 * <code>implementation</code> element.
 */
public interface ExtendedImplementation extends Implementation {
  /**
   * Returns the language of the implementation.
   * 
   * @return the language of the implementation.
   */
  String getLanguage();

  /**
   * Set the language of the implementation.
   * 
   * @param language the language of the implementation.
   */
  void setLanguage(String language);

  /**
   * Returns the value of the <code>hasConstructor</code> attribute.
   * 
   * @return the value of the <code>hasConstructor</code> attribute.
   */
  String getHasConstructor();

  /**
   * Sets the value of the <code>hasConstructor</code> attribute.
   * 
   * @param hasConstructor the value of the <code>hasConstructor</code>
   *          attribute. Must be either <code>"true"</code> or
   *          <code>"false"</code>.
   * @see #getHasConstructor()
   */
  void setHasConstructor(String hasConstructor);

  /**
   * Returns the value of the <code>hasDestructor</code> attribute.
   * 
   * @return the value of the <code>hasDestructor</code> attribute.
   */
  String getHasDestructor();

  /**
   * Sets the value of the <code>hasDestructor</code> attribute.
   * 
   * @param hasDestructor the value of the <code>hasDestructor</code> attribute.
   *          Must be either <code>"true"</code> or <code>"false"</code>.
   * @see #getHasConstructor()
   */
  void setHasDestructor(String hasDestructor);
}
